<template>
  <el-dialog class="filterDialog" :title="title" :visible.sync="dialogShow" :show-close="true"
             :close-on-click-modal="false" :modal-append-to-body="false" v-if="dialogShow"
             :append-to-body="appendToBody" :width="dialogWidth">
    <list-condition-template ref="table" :form="form" :formLabel="formLabel" v-loading="loading"
                             element-loading-custom-class="customLoading" :tableData="tableData"
                             :total="total" :multipleSelected="multipleSelected"
                             @page-info-change="handlePageInfoChange" @selected="handleSelected"
                             :emptyText="emptyText" :isShowPage="isShowPage"
                             :limiteSelectedNum="limiteSelectedNum">
      <template slot="otherElement" slot-scope="scope">
         <slot name="condition" :data="scope.data"></slot>
      </template>
      <template slot="columns">
        <slot name="columns"></slot>
      </template>
    </list-condition-template>
    <div slot="footer" class="dialog-footer">
      <el-button size="mini" type="primary" v-if="multipleSelected" @click="closeDialog">确定
      </el-button>
      <el-button size="mini" @click="dialogShow = false">关闭</el-button>
    </div>
  </el-dialog>
</template>
<script>
export default {
  props: {
    /**
         * 对话框显示状态
         */
    show: {
      type: Boolean,
      default: false
    },
    /**
         * 数据行
         */
    tableData: {
      type: Array,
      default: function () {
        return []
      }
    },
    /**
         * 数据总数
         */
    total: {
      type: Number,
      default: 0
    },
    title: {
      type: String,
      default: '添加品牌'
    },
    /**
         * 是否嵌套弹出框
         */
    appendToBody: {
      type: Boolean,
      default: false
    },
    /**
         * 表格遮罩
         */
    loading: {
      type: Boolean,
      default: false
    },
    /**
         * 查询条件
         */
    form: {
      type: Object,
      default: function () {
        return {}
      }
    },
    /**
         *标签数据
         */
    formLabel: {
      type: Array,
      default: function () {
        return []
      }
    },
    /**
     * 是否多选
     */
    multipleSelected: {
      type: Boolean,
      default: false
    },
    /**
     * 表格空数据时显示文字
     */
    emptyText: {
      type: String,
      default: '暂无数据'
    },
    isShowPage: {
      type: Boolean,
      default: true
    },
    /**
     * 限制勾选个数
     */
    limiteSelectedNum: {
      type: Number,
      default: null
    },
    /**
   * 弹出框默认宽度
   */
    dialogWidth: {
      type: String,
      default: '50%'
    }
  },
  data () {
    return {
      dialogShow: false
    }
  },
  watch: {
    /**
         * 监控外部显示变量变化
         * 传递到dialog组件
         */
    show: function (newShow, oldShow) {
      this.dialogShow = newShow
      if (this.dialogShow) {
        this.$emit('page-info-change', { pageNum: 1, pageSize: 10 })
      }
    },
    /**
         * 监控内部显示属性变化
         * 传递到外部调用变量
         */
    dialogShow: function (newDialogShow, oldDialogShow) {
      this.$emit('update:show', newDialogShow)
    }
  },
  methods: {
    /**
     * 重置条件
     */
    reloadCurrent () {
      this.$refs.table.reloadCurrent()
    },
    /**
     * 主动关闭对话框
     */
    closeDialog () {
      this.$emit('update:show', false)
      this.onClose()
    },
    /**
     * 触发关闭事件
     */
    onClose () {
      this.$emit('close')
    },
    /**
     * 行选中事件处理
     * @param {*} rows 行数据
     */
    handleSelected (rows) {
      this.$emit('selected', rows)
    },

    /**
         * 当分页信息变动的时候
         */
    handlePageInfoChange (pageInfo) {
      this.onPageInfoChage(pageInfo)
    },
    /**
         * 触发分页信息变化事件
         */
    onPageInfoChage (pageInfo) {
      this.$emit('page-info-change', pageInfo)
    },
    /**
         * 重置条件并触发条件变化事件
         */
    changeCondition () {
      this.$refs.table.changeCondition()
    }
  }
}
</script>
<style lang="scss">
.filterDialog {
  .commonForm,
  .main-b-style {
    padding: 0;
  }
}
</style>
